@@ -78,8 +78,11 @@ mcp2matrix <- function(model, linfct) {
     nhypo <- names(linfct)
     checknm <- nhypo %in% rownames(factors) & sapply(mf[nhypo], is.factor)
     if (!all(checknm)) 
-        stop("Factor(s) ", nhypo[!checknm], " have been specified in ",
-             sQuote("linfct"), " but cannot be found in ", sQuote("model"), "!")
+        stop("Variable(s) ", nhypo[!checknm], " have been specified as factor in ",
+             sQuote("linfct"), " but cannot be found as factor in ", sQuote("model"), "! ", 
+             "Variable(s) ", sQuote(paste(nhypo[!checknm], collapse = ", ")), " of class ", 
+              sQuote(paste(sapply(mf[nhypo[!checknm]], class), collapse = ", ")), 
+             " is/are contained in ", sQuote("model"), ".")
     m <- c()
     ctype <- c()
     for (nm in nhypo) {
